Unified · Split
| @@ -1,3 +1,85 @@ | ||
| 1 | +2011-08-02 v0.9.7 "Cayuga" | |
| 2 | + Our third named release, focused on a faster, higher quality, encoder. | |
| 3 | + | |
| 4 | + - Upgrading: | |
| 5 | + This release is backwards compatible with Aylesbury (v0.9.5) and | |
| 6 | + Bali (v0.9.6). Users of older releases should refer to the Upgrading | |
| 7 | + notes in this document for that release. | |
| 8 | + | |
| 9 | + - Enhancements: | |
| 10 | + Stereo 3D format support for vpxenc | |
| 11 | + Runtime detection of available processor cores. | |
| 12 | + Allow specifying --end-usage by enum name | |
| 13 | + vpxdec: test for frame corruption | |
| 14 | + vpxenc: add quantizer histogram display | |
| 15 | + vpxenc: add rate histogram display | |
| 16 | + Set VPX_FRAME_IS_DROPPABLE | |
| 17 | + update configure for ios sdk 4.3 | |
| 18 | + Avoid text relocations in ARM vp8 decoder | |
| 19 | + Generate a vpx.pc file for pkg-config. | |
| 20 | + New ways of passing encoded data between encoder and decoder. | |
| 21 | + | |
| 22 | + - Speed: | |
| 23 | + This release includes across-the-board speed improvements to the | |
| 24 | + encoder. On x86, these measure at approximately 11.5% in Best mode, | |
| 25 | + 21.5% in Good mode (speed 0), and 22.5% in Realtime mode (speed 6). | |
| 26 | + On ARM Cortex A9 with Neon extensions, real-time encoding of video | |
| 27 | + telephony content is 35% faster than Bali on single core and 48% | |
| 28 | + faster on multi-core. On the NVidia Tegra2 platform, real time | |
| 29 | + encoding is 40% faster than Bali. | |
| 30 | + | |
| 31 | + Decoder speed was not a priority for this release, but improved | |
| 32 | + approximately 8.4% on x86. | |
| 33 | + | |
| 34 | + Reduce motion vector search on alt-ref frame. | |
| 35 | + Encoder loopfilter running in its own thread | |
| 36 | + Reworked loopfilter to precalculate more parameters | |
| 37 | + SSE2/SSSE3 optimizations for build_predictors_mbuv{,_s}(). | |
| 38 | + Make hor UV predict ~2x faster (73 vs 132 cycles) using SSSE3. | |
| 39 | + Removed redundant checks | |
| 40 | + Reduced structure sizes | |
| 41 | + utilize preload in ARMv6 MC/LPF/Copy routines | |
| 42 | + ARM optimized quantization, dfct, variance, subtract | |
| 43 | + Increase chrow row alignment to 16 bytes. | |
| 44 | + disable trellis optimization for first pass | |
| 45 | + Write SSSE3 sub-pixel filter function | |
| 46 | + Improve SSE2 half-pixel filter funtions | |
| 47 | + Add vp8_sub_pixel_variance16x8_ssse3 function | |
| 48 | + Reduce unnecessary distortion computation | |
| 49 | + Use diamond search to replace full search | |
| 50 | + Preload reference area in sub-pixel motion search (real-time mode) | |
| 51 | + | |
| 52 | + - Quality: | |
| 53 | + This release focused primarily on one-pass use cases, including | |
| 54 | + video conferencing. Low latency data rate control was significantly | |
| 55 | + improved, improving streamability over bandwidth constrained links. | |
| 56 | + Added support for error concealment, allowing frames to maintain | |
| 57 | + visual quality in the presence of substantial packet loss. | |
| 58 | + | |
| 59 | + Add rc_max_intra_bitrate_pct control | |
| 60 | + Limit size of initial keyframe in one-pass. | |
| 61 | + Improve framerate adaptation | |
| 62 | + Improved 1-pass CBR rate control | |
| 63 | + Improved KF insertion after fades to still. | |
| 64 | + Improved key frame detection. | |
| 65 | + Improved activity masking (lower PSNR impact for same SSIM boost) | |
| 66 | + Improved interaction between GF and ARFs | |
| 67 | + Adding error-concealment to the decoder. | |
| 68 | + Adding support for independent partitions | |
| 69 | + Adjusted rate-distortion constants | |
| 70 | + | |
| 71 | + | |
| 72 | + - Bug Fixes: | |
| 73 | + Removed firstpass motion map | |
| 74 | + Fix parallel make install | |
| 75 | + Fix multithreaded encoding for 1 MB wide frame | |
| 76 | + Fixed iwalsh_neon build problems with RVDS4.1 | |
| 77 | + Fix semaphore emulation, spin-wait intrinsics on Windows | |
| 78 | + Fix build with xcode4 and simplify GLOBAL. | |
| 79 | + Mark ARM asm objects as allowing a non-executable stack. | |
| 80 | + Fix vpxenc encoding incorrect webm file header on big endian | |
| 81 | + | |
| 82 | + | |
| 1 | 83 | 2011-03-07 v0.9.6 "Bali" |
| 2 | 84 | Our second named release, focused on a faster, higher quality, encoder. |
| 3 | 85 | |